@@ -1,6 +1,6 @@
 import requests
 from click.testing import CliRunner
-from pgn_to_sqlite.cli import build_pgn_dict, convert_to_snake_case, main
+from pgn_to_sqlite.cli import build_pgn_dict, convert_to_snake_case, cli
 
 
 def test_snake_case_conversion():
@@ -9,7 +9,7 @@ def test_snake_case_conversion():
 
 
 def test_build_png_dict_from_chess_dotcom():
-    with open("tests/test_pgn_file_chess_dotcom.pgn", "r") as f:
+    with open("tests/game_files/test_pgn_file_chess_dotcom.pgn", "r") as f:
         pgn_str = f.read()
         result = build_pgn_dict(pgn_str)
 
@@ -18,7 +18,7 @@ def test_build_png_dict_from_chess_dotcom():
 
 
 def test_build_png_dict_from_lichess():
-    with open("tests/test_pgn_file_lichess.pgn", "r") as f:
+    with open("tests/game_files/test_pgn_file_lichess.pgn", "r") as f:
         pgn_str = f.read()
         result = build_pgn_dict(pgn_str)
 
@@ -34,6 +34,12 @@ def test_chess_dotcom_api_endpoint():
 def test_ValueError_on_invalid_args():
     runner = CliRunner()
     result = runner.invoke(
-        main, ["invalid_site", "-u", "endlesstrax", "-o", "games.db"]
+        cli, ["-u", "endlesstrax", "-o", "games.db", "fetch", "invaild"]
     )
     assert result.exit_code == 1
+
+
+def test_folder_input_file():
+    runner = CliRunner()
+    result = runner.invoke(cli, ["-o", "games.db", "save", "tests/game_files/"])
+    assert result.exit_code == 0
